Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DistSQLContext ¶
type DistSQLContext struct {
WarnHandler contextutil.WarnAppender
InRestrictedSQL bool
Client kv.Client
EnabledRateLimitAction bool
EnableChunkRPC bool
OriginalSQL string
KVVars *tikvstore.Variables
KvExecCounter *stmtstats.KvExecCounter
SessionMemTracker *memory.Tracker
Location *time.Location
RuntimeStatsColl *execdetails.RuntimeStatsColl
SQLKiller *sqlkiller.SQLKiller
CPUUsage *ppcpuusage.SQLCPUUsages
ErrCtx errctx.Context
// TiFlash related configurations
TiFlashReplicaRead tiflash.ReplicaRead
TiFlashMaxThreads int64
TiFlashMaxBytesBeforeExternalJoin int64
TiFlashMaxBytesBeforeExternalGroupBy int64
TiFlashMaxBytesBeforeExternalSort int64
TiFlashMaxQueryMemoryPerNode int64
TiFlashQuerySpillRatio float64
DistSQLConcurrency int
ReplicaReadType kv.ReplicaReadType
WeakConsistency bool
RCCheckTS bool
NotFillCache bool
TaskID uint64
Priority mysql.PriorityEnum
ResourceGroupTagger *kv.ResourceGroupTagBuilder
EnablePaging bool
MinPagingSize int
MaxPagingSize int
RequestSourceType string
ExplicitRequestSourceType string
StoreBatchSize int
ResourceGroupName string
LoadBasedReplicaReadThreshold time.Duration
RunawayChecker resourcegroup.RunawayChecker
TiKVClientReadTimeout uint64
ReplicaClosestReadThreshold int64
ConnectionID uint64
SessionAlias string
ExecDetails *execdetails.SyncExecDetails
}
DistSQLContext provides all information needed by using functions in `distsql`
func (*DistSQLContext) AppendWarning ¶
func (dctx *DistSQLContext) AppendWarning(warn error)
AppendWarning appends the warning to the warning handler.
func (*DistSQLContext) Detach ¶
func (dctx *DistSQLContext) Detach() *DistSQLContext
Detach detaches this context from the session context.
NOTE: Though this session context can be used parallelly with this context after calling it, the `StatementContext` cannot. The session context should create a new `StatementContext` before executing another statement.
Click to show internal directories.
Click to hide internal directories.